apply_ZINB: Apply the algorithms to make decisions for Thompson sampling...

View source: R/count_ts.R

apply_ZINBR Documentation

Apply the algorithms to make decisions for Thompson sampling Zero-inflated Negative Binomial (TS-ZINB) algorithm

Description

Apply the algorithms to make decisions for Thompson sampling Zero-inflated Negative Binomial (TS-ZINB) algorithm

Usage

apply_ZINB(context, beta_ZINB, gamma_ZINB)

Arguments

context

context at the current decision time

beta_ZINB

the randomly sampled Bayesian estimate for the Poisson component

gamma_ZINB

the randomly sampled Bayesian estimate for the zero component

Value

Intervention option

Examples

apply_ZINB(matrix(1:10, nrow = 2),matrix(11:20, nrow = 5),matrix(21:30, nrow = 5))

countts documentation built on May 29, 2024, 10:23 a.m.

Related to apply_ZINB in countts...