| apply_ZIP | R Documentation |
Apply the algorithms to make decisions for Thompson sampling Zero-inflated Poisson (TS-ZIP) algorithm
apply_ZIP(context, beta_ZIP, gamma_ZIP)
context |
context at the current decision time |
beta_ZIP |
the randomly sampled Bayesian estimate for the Poisson component |
gamma_ZIP |
the randomly sampled Bayesian estimate for the zero component |
Intervention option
apply_ZIP(matrix(1:10, nrow = 2),matrix(11:20, nrow = 5),matrix(21:30, nrow = 5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.