apply_laplacePoisson: Apply the algorithms to make decisions for Thompson sampling...

View source: R/count_ts.R

apply_laplacePoissonR Documentation

Apply the algorithms to make decisions for Thompson sampling Poisson (TS-Poisson) algorithms

Description

Apply the algorithms to make decisions for Thompson sampling Poisson (TS-Poisson) algorithms

Usage

apply_laplacePoisson(context, beta_laplacePoisson)

Arguments

context

context at the current decision time

beta_laplacePoisson

the randomly sampled Bayesian estimate

Value

Intervention option

Examples

apply_laplacePoisson(matrix(1:10, nrow = 2),matrix(11:20, nrow = 5))

countts documentation built on May 29, 2024, 10:23 a.m.