apply_linearTS: Apply the algorithms to make decisions for Linear Thompson...

View source: R/count_ts.R

apply_linearTSR Documentation

Apply the algorithms to make decisions for Linear Thompson sampling (TS) algorithms

Description

Apply the algorithms to make decisions for Linear Thompson sampling (TS) algorithms

Usage

apply_linearTS(context, beta_linearTS)

Arguments

context

context at the current decision time

beta_linearTS

the randomly sampled Bayesian estimate

Value

Intervention option

Examples

apply_linearTS(matrix(1:10, nrow = 2),matrix(11:20, nrow = 5))

countts documentation built on May 29, 2024, 10:23 a.m.