| apply_ZINB | R Documentation |
Apply the algorithms to make decisions for Thompson sampling Zero-inflated Negative Binomial (TS-ZINB) algorithm
apply_ZINB(context, beta_ZINB, gamma_ZINB)
context |
context at the current decision time |
beta_ZINB |
the randomly sampled Bayesian estimate for the Poisson component |
gamma_ZINB |
the randomly sampled Bayesian estimate for the zero component |
Intervention option
apply_ZINB(matrix(1:10, nrow = 2),matrix(11:20, nrow = 5),matrix(21:30, nrow = 5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.